 /***************************************************************************\
|*                                                                           *|
|*        Copyright (c) 1999 NVIDIA, Corp.  All rights reserved.             *|
|*                                                                           *|
|*     NOTICE TO USER:   The source code  is copyrighted under  U.S. and     *|
|*     international laws.   NVIDIA, Corp. of Sunnyvale, California owns     *|
|*     the copyright  and as design patents  pending  on the design  and     *|
|*     interface  of the NV chips.   Users and possessors of this source     *|
|*     code are hereby granted  a nonexclusive,  royalty-free  copyright     *|
|*     and  design  patent license  to use this code  in individual  and     *|
|*     commercial software.                                                  *|
|*                                                                           *|
|*     Any use of this source code must include,  in the user documenta-     *|
|*     tion and  internal comments to the code,  notices to the end user     *|
|*     as follows:                                                           *|
|*                                                                           *|
|*     Copyright (c) 1993-1997  NVIDIA, Corp.    NVIDIA  design  patents     *|
|*     pending in the U.S. and foreign countries.                            *|
|*                                                                           *|
|*     NVIDIA, CORP.  MAKES  NO REPRESENTATION ABOUT  THE SUITABILITY OF     *|
|*     THIS SOURCE CODE FOR ANY PURPOSE.  IT IS PROVIDED "AS IS" WITHOUT     *|
|*     EXPRESS OR IMPLIED WARRANTY OF ANY KIND.  NVIDIA, CORP. DISCLAIMS     *|
|*     ALL WARRANTIES  WITH REGARD  TO THIS SOURCE CODE,  INCLUDING  ALL     *|
|*     IMPLIED   WARRANTIES  OF  MERCHANTABILITY  AND   FITNESS   FOR  A     *|
|*     PARTICULAR  PURPOSE.   IN NO EVENT SHALL NVIDIA, CORP.  BE LIABLE     *|
|*     FOR ANY SPECIAL, INDIRECT, INCIDENTAL,  OR CONSEQUENTIAL DAMAGES,     *|
|*     OR ANY DAMAGES  WHATSOEVER  RESULTING  FROM LOSS OF USE,  DATA OR     *|
|*     PROFITS,  WHETHER IN AN ACTION  OF CONTRACT,  NEGLIGENCE OR OTHER     *|
|*     TORTIOUS ACTION, ARISING OUT  OF OR IN CONNECTION WITH THE USE OR     *|
|*     PERFORMANCE OF THIS SOURCE CODE.                                      *|
|*                                                                           *|
 \***************************************************************************/


/*
 * Registry variables.
 *
 * These are defined here and used throughout resman.
 * They must be set by when loading the module using insmod.
 *
 * Registry names within linux look like: NVreg_NAME.
 * The 'NAME' portion is the leaf windows registry name with spaces
 * converted to '_'.  So 'Display Type' becomes 'Display_Type'
 *
 * TODO:
 *
 *    persistence
 *        This could be added by saving them outside resman using an ioctl
 *        and then playing them back at startup.
 *
 *    device dependence
 *        currently just one global namespace
 *        This could be easily added as NVreg_01_foofoo to mean symbol foofoo
 *        on the 2nd card in system.
 *
 */

#ifndef __KERNEL__
#  define __KERNEL__
#endif
#ifndef MODULE
#  define MODULE
#endif

#define __NO_VERSION__
#define EXPORT_SYMTAB
#include <linux/module.h>

#define RM_HEADERS_MINIMAL      // we just need top half of nvrm.h, not the entire
#include <nvrm.h>

/*
 * The 2nd argument to MODULE_PARM is used to verify parameters given to the module.
 * It should be a string in the following format:
 *   	[min[-max]]{b,h,i,l,s}
 * The MIN and MAX specifiers delimit the length of the array.  If MAX
 * is omitted, it defaults to MIN; if both are omitted, the default is 1.
 * The final character is a type specifier:
 *      b	byte
 *	h	short
 *	i	int
 *	l	long
 *	s	string
 *
 * Note: much of resman considers the *existence* of a flag to be sufficient.
 *       Ie: value is ignored.
 */

U032 NVreg_resman_debuglevel = ~0;
MODULE_PARM(NVreg_resman_debuglevel, "i");

#if 0
/* We normally detect memory type on TNT cards by scanning the embedded bios.
 * Unfortunately, we've seen some cases where a TNT card has been flashed with
 * the wrong bios. For example, an SDRAM-based TNT has been flashed with an SGRAM
 * bios, and therefore claims to be an SGRAM-based TNT. We've therefore provided
 * an override here. Ifdef'ing in these variables will override the card's bios.
 * Make sure to set the value to the correct type of memory.
 * Note that we can only do so much here. There are border cases where even this
 * fails. For example, if 2 TNT cards are in the same system, one SGRAM, one SDRAM.
 */
/* SDRAM = 1, SGRAM = 2 */
U032 NVreg_VideoMemoryTypeOverride = 1;
MODULE_PARM(NVreg_VideoMemoryTypeOverride, "i");
#endif

/*
 * we've had problems with some Via chipsets in 4x mode, so we force them back
 * down to 2x mode. If you'd like to experiment with retaining 4x mode,
 * try setting this value to '1.' If that hangs the system, you're stuck with
 * 2x mode, there's nothing we can do about it.
 */
U032 NVreg_EnableVia4x = 0;
MODULE_PARM(NVreg_EnableVia4x, "i");

/* bit-wise mask of acceptable AGP rates.
 * Normally, the driver will compare speed modes of the chipset & card,
 * picking the highest common rate. This key forces a maximum limit, to limit
 * the driver to lower speeds. The driver will not attempt a speed beyond what
 * the chipset and card claim they are capable of.
 *   0x7 = 1 | 2 | 4
 */
U032 NVreg_ReqAGPRate = 0x7;
MODULE_PARM(NVreg_ReqAGPRate, "i");



